{% extends "layout.html" %}
{% set title = 'Overview' %}
{% block body %}
<div class="section">
  <h1>PySide {{ version }} Reference</h1>

    <p><a href="http://www.qtsoftware.com/">Qt</a> is a cross-platform application framework from Qt Software (owned by Nokia).
    It features a large number of libraries providing services like network abstraction and XML handling, along with a very rich
    GUI package, allowing C++ developers to write their applications once and run them unmodified in different systems.
    PySide aims to provide Python developers access to the Qt libraries in the most natural way.</p>

    <p>PySide is built using the <a href="http://www.pyside.org/docs/shiboken">Shiboken</a> binding generator.</p>

  <h2>Notes</h2>

    <h3>About 0 vs None</h3>

    <p>The PySide class reference documentation is automatically generated from the original Qt documentation for C++, some parts were tuned to fit the Python world. However, it's not possible to rewrite all Qt docs as it would require a really huge effort, so if the documentation says you can use 0 on an QObject argument, interpret it as None.</p>

    <h3>About keyword arguments</h3>

    <p>Only optional arguments can be used as keyword arguments.</p>

  <h2>Modules</h2>

  <table class="contentstable" align="center" ><tr>
    <td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtCore/index") }}">QtCore</a><br/>
         <span class="linkdescr">core non-GUI functionality</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtGui/index") }}">QtGui</a><br/>
         <span class="linkdescr">extends QtCore with GUI functionality.</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtDeclarative/index") }}">QtDeclarative</a><br/>
         <span class="linkdescr">a declarative framework for building highly dynamic, custom user interfaces.</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtHelp/index") }}">QtHelp</a><br/>
         <span class="linkdescr">provides classes for integrating online documentation in applications</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtMultimedia/index") }}">QtMultimedia</a><br/>
         <span class="linkdescr">provides low-level multimedia functionality</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtNetwork/index") }}">QtNetwork</a><br/>
         <span class="linkdescr">offers classes that allow you to write TCP/IP clients and servers</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtOpenGL/index") }}">QtOpenGL</a><br/>
         <span class="linkdescr">offers classes that make it easy to use OpenGL in Qt applications</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtScript/index") }}">QtScript</a><br/>
         <span class="linkdescr">provides classes for making Qt applications scriptable</span></p>
    </td>
    <td width="50%">
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtScriptTools/index") }}">QtScriptTools</a><br/>
         <span class="linkdescr">provides additional components for applications that use Qt Script</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtSql/index") }}">QtSql</a><br/>
         <span class="linkdescr">helps you provide seamless database integration to your Qt applications</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtSvg/index") }}">QtSvg</a><br/>
         <span class="linkdescr">provides classes for displaying the contents of SVG files</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtUiTools/index") }}">QtUiTools</a><br/>
         <span class="linkdescr">provides classes to handle forms created with Qt Designer</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtXml/index") }}">QtXml</a><br/>
         <span class="linkdescr">provides a stream reader and writer for XML documents</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/QtWebKit/index") }}">QtWebkit</a><br/>
         <span class="linkdescr">provides a Web browser engine</span></p>
      <p class="biglink"><a class="biglink" href="{{ pathto("PySide/phonon/index") }}">Phonon</a><br/>
         <span class="linkdescr">cross-platform multimedia framework that enables the use of audio and video
          content in Qt applications</span></p>
    </td></tr>
  </table>

  <h2>Tutorials and examples</h2>

  <p>A collection of <a href="{{ pathto("tutorials/index") }}">tutorials</a> and "walkthrough" guides are provided with PySide to help new users get started with PySide development. These documents were ported from C++ to Python and cover a range of topics, from basic use of widgets to step-by-step <a href="{{ pathto("tutorials/index") }}">tutorials</a> that show how an application is put together.</p>

  <h2>Other stuff</h2>

  <ul>
    <li class="toctree-l1"><a class="reference internal" href="pysideapi2.html">PySide API 2</a></li>
    <li class="toctree-l1"><a class="reference internal" href="pysideversion.html">Getting PySide and Qt version</a></li>
  </ul>
</div>
{% endblock %}
