/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the example classes of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

//! [0]
    i = QInputDialog().getInteger(self, self.tr("QInputDialog().getInteger()"),
                                     self.tr("Percentage:"), 25, 0, 100, 1, ok)
    if ok:
        self.integerLabel.setText(self.tr("%1%").arg(i))
//! [0]

//! [1]
    d = QInputDialog().getDouble(self, self.tr("QInputDialog().getDouble()"),
                                       self.tr("Amount:"), 37.56, -10000, 10000, 2, ok)
    if ok:
        doubleLabel.setText(QString("$%1").arg(d))
//! [1]

//! [2]
    items = [self.tr("Spring"), self.tr("Summer"), self.tr("Fall"), self.tr("Winter")]

    item = QInputDialog().getItem(self, self.tr("QInputDialog().getItem()"),
                                         selftr("Season:"), items, 0, False, ok)
    if ok and not item.isEmpty():
        itemLabel.setText(item)
//! [2]

//! [3]
    text = QInputDialog::getText(self, self.tr("QInputDialog().getText()"),
                                         self.tr("User name:"), QLineEdit.Normal,
                                         QDir().home().dirName(), ok)
    if ok and text:
        textLabel.setText(text)
//! [3]
