//! [0]
sb.setPrefix("$")
//! [0]


//! [1]
sb.setSuffix(" km")
//! [1]


//! [2]
setRange(minimum, maximum)
//! [2]


//! [3]
setMinimum(minimum)
setMaximum(maximum)
//! [3]


//! [4]
spinbox.setPrefix("$")
//! [4]


//! [5]
spinbox.setSuffix(" km")
//! [5]


//! [6]
setRange(minimum, maximum)
//! [6]


//! [7]
setMinimum(minimum)
setMaximum(maximum)
//! [7]
